@@ -1,43 +1,29 @@
 package Bencher::Scenario::Perl::Startup;
 
-our $DATE = '2016-01-07'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-13'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
+use App::perlbrew;
 use File::Which;
 
 my $participants = [];
 
-if (my $perlbrew_path = which("perlbrew")) {
-    my $perlbrew_root = $perlbrew_path;
-    $perlbrew_root =~ s!/bin/perlbrew\z!!;
-    my $out = `perlbrew list`;
-
-    my @perls;
-    while ($out =~ /^\s*\*?\s*(.+)/gm) {
-        push @perls, $1;
-    }
-
-    for my $perl (@perls) {
-        my ($perl_ver) = $perl =~ /perl-(.+)/;
-
+my $pb = App::perlbrew->new;
+for my $perl ($pb->installed_perls) {
+    push @$participants, {
+        name => "$perl->{name} -e1",
+        cmdline => [$perl->{executable}, "-e1"],
+    };
+    if (version->parse($perl->{version}) >= version->parse("5.10.0")) {
         push @$participants, {
-            name => "$perl -e1",
-            cmdline => ["$perlbrew_root/perls/$perl/bin/perl", "-e1"],
+            name => "$perl->{name} -E1",
+            cmdline => [$perl->{executable}, "-E1"],
         };
-
-        if (version->parse($perl_ver) >= version->parse("5.10.0")) {
-            push @$participants, {
-                name => "$perl -E1",
-                cmdline => ["$perlbrew_root/perls/$perl/bin/perl", "-E1"],
-            };
-        }
     }
-} else {
-    warn "Please install perlbrew so I can easily locate the different perls";
 }
 
 our $scenario = {
@@ -61,7 +47,7 @@ Bencher::Scenario::Perl::Startup - Benchmark startup time of perls
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::Perl::Startup (from Perl distribution Bencher-Scenarios-Perl), released on 2016-01-07.
+This document describes version 0.03 of Bencher::Scenario::Perl::Startup (from Perl distribution Bencher-Scenarios-Perl), released on 2016-03-13.
 
 =head1 SYNOPSIS
 
@@ -75,6 +61,22 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =over
 
+=item * perl-5.6.2 -e1 (command)
+
+Command line:
+
+ /home/s1/perl5/perlbrew/perls/perl-5.6.2/bin/perl -e1
+
+
+
+=item * perl-5.8.9 -e1 (command)
+
+Command line:
+
+ /home/s1/perl5/perlbrew/perls/perl-5.8.9/bin/perl -e1
+
+
+
 =item * perl-5.10.1 -e1 (command)
 
 Command line:
@@ -155,19 +157,19 @@ Command line:
 
 
 
-=item * perl-5.20.3 -e1 (command)
+=item * perl-5.20.2 -e1 (command)
 
 Command line:
 
- /home/s1/perl5/perlbrew/perls/perl-5.20.3/bin/perl -e1
+ /home/s1/perl5/perlbrew/perls/perl-5.20.2/bin/perl -e1
 
 
 
-=item * perl-5.20.3 -E1 (command)
+=item * perl-5.20.2 -E1 (command)
 
 Command line:
 
- /home/s1/perl5/perlbrew/perls/perl-5.20.3/bin/perl -E1
+ /home/s1/perl5/perlbrew/perls/perl-5.20.2/bin/perl -E1
 
 
 
@@ -187,35 +189,19 @@ Command line:
 
 
 
-=item * perl-5.22.1 -e1 (command)
+=item * perl-5.22.1-thread-multi-ld -e1 (command)
 
 Command line:
 
- /home/s1/perl5/perlbrew/perls/perl-5.22.1/bin/perl -e1
+ /home/s1/perl5/perlbrew/perls/perl-5.22.1-thread-multi-ld/bin/perl -e1
 
 
 
-=item * perl-5.22.1 -E1 (command)
+=item * perl-5.22.1-thread-multi-ld -E1 (command)
 
 Command line:
 
- /home/s1/perl5/perlbrew/perls/perl-5.22.1/bin/perl -E1
-
-
-
-=item * perl-5.6.2 -e1 (command)
-
-Command line:
-
- /home/s1/perl5/perlbrew/perls/perl-5.6.2/bin/perl -e1
-
-
-
-=item * perl-5.8.9 -e1 (command)
-
-Command line:
-
- /home/s1/perl5/perlbrew/perls/perl-5.8.9/bin/perl -e1
+ /home/s1/perl5/perlbrew/perls/perl-5.22.1-thread-multi-ld/bin/perl -E1
 
 
 
@@ -223,32 +209,32 @@ Command line:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m Perl::Startup >>):
 
- +-----+-----------------+------+--------+---------+---------+
- | seq | name            | rate | time   | errors  | samples |
- +-----+-----------------+------+--------+---------+---------+
- | 15  | perl-5.22.1 -E1 | 183  | 5.48ms | 5.4e-06 | 915     |
- | 13  | perl-5.22.0 -E1 | 186  | 5.39ms | 5.3e-06 | 679     |
- | 11  | perl-5.20.3 -E1 | 186  | 5.37ms | 5.3e-06 | 1180    |
- | 9   | perl-5.18.4 -E1 | 191  | 5.22ms | 5.2e-06 | 905     |
- | 7   | perl-5.16.3 -E1 | 193  | 5.19ms | 5.2e-06 | 1060    |
- | 5   | perl-5.14.4 -E1 | 196  | 5.1ms  | 5.1e-06 | 1158    |
- | 3   | perl-5.12.5 -E1 | 198  | 5.06ms | 5e-06   | 1040    |
- | 1   | perl-5.10.1 -E1 | 203  | 4.93ms | 4.8e-06 | 1301    |
- | 14  | perl-5.22.1 -e1 | 220  | 4.55ms | 4.4e-06 | 1542    |
- | 12  | perl-5.22.0 -e1 | 220  | 4.54ms | 4.4e-06 | 1680    |
- | 10  | perl-5.20.3 -e1 | 222  | 4.5ms  | 4.4e-06 | 1402    |
- | 6   | perl-5.16.3 -e1 | 225  | 4.44ms | 4.4e-06 | 1541    |
- | 8   | perl-5.18.4 -e1 | 226  | 4.43ms | 4.4e-06 | 1332    |
- | 4   | perl-5.14.4 -e1 | 227  | 4.41ms | 4.3e-06 | 1335    |
- | 2   | perl-5.12.5 -e1 | 228  | 4.38ms | 4.4e-06 | 1219    |
- | 0   | perl-5.10.1 -e1 | 232  | 4.31ms | 4.2e-06 | 1207    |
- | 17  | perl-5.8.9 -e1  | 232  | 4.3ms  | 4.3e-06 | 948     |
- | 16  | perl-5.6.2 -e1  | 247  | 4.04ms | 3.9e-06 | 1184    |
- +-----+-----------------+------+--------+---------+---------+
+ +---------------------------------+-----------+-----------+------------+---------+---------+
+ | participant                     | rate (/s) | time (ms) | vs_slowest | errors  | samples |
+ +---------------------------------+-----------+-----------+------------+---------+---------+
+ | perl-5.22.1-thread-multi-ld -E1 | 324       | 3.08      | 1          | 3.1e-06 | 425     |
+ | perl-5.22.0 -E1                 | 335       | 2.99      | 1.03       | 2.9e-06 | 621     |
+ | perl-5.20.2 -E1                 | 341       | 2.93      | 1.05       | 2.9e-06 | 535     |
+ | perl-5.16.3 -E1                 | 342       | 2.92      | 1.06       | 2.7e-06 | 919     |
+ | perl-5.18.4 -E1                 | 343       | 2.91      | 1.06       | 2.9e-06 | 555     |
+ | perl-5.14.4 -E1                 | 354       | 2.83      | 1.09       | 2.7e-06 | 897     |
+ | perl-5.12.5 -E1                 | 364       | 2.75      | 1.12       | 2.7e-06 | 416     |
+ | perl-5.10.1 -E1                 | 370       | 2.7       | 1.14       | 2.7e-06 | 457     |
+ | perl-5.22.1-thread-multi-ld -e1 | 410       | 2.44      | 1.26       | 2.4e-06 | 143     |
+ | perl-5.22.0 -e1                 | 417       | 2.4       | 1.29       | 2.4e-06 | 98      |
+ | perl-5.18.4 -e1                 | 419       | 2.39      | 1.29       | 2.3e-06 | 432     |
+ | perl-5.20.2 -e1                 | 423       | 2.36      | 1.31       | 2.3e-06 | 156     |
+ | perl-5.8.9 -e1                  | 428       | 2.34      | 1.32       | 2.3e-06 | 61      |
+ | perl-5.16.3 -e1                 | 432       | 2.32      | 1.33       | 2.3e-06 | 198     |
+ | perl-5.12.5 -e1                 | 434       | 2.31      | 1.34       | 2.2e-06 | 48      |
+ | perl-5.14.4 -e1                 | 433       | 2.31      | 1.33       | 2.3e-06 | 111     |
+ | perl-5.10.1 -e1                 | 435       | 2.3       | 1.34       | 2.1e-06 | 79      |
+ | perl-5.6.2 -e1                  | 455       | 2.2       | 1.4        | 2.1e-06 | 203     |
+ +---------------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
@@ -256,10 +242,6 @@ Conclusion: in general newer versions of perl has larger startup overhead than
 previous ones. If startup overhead is important to you, use C<-e> instead of
 C<-E> unless necessary.
 
-=head1 SEE ALSO
-
-L<Bencher::Scenario::Interpreters>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-Perl>.
@@ -276,6 +258,10 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Bencher::Scenario::Interpreters>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
